@@ -34,20 +34,89 @@ class SystemDesign(object):
     strings_in_parallel: t.Optional[int] = opt_field()
     azimuth: t.Optional[float] = opt_field()
 
+
 @dataclass_json
 @dataclass
-class Inverter(object):
+class BaseInverter(object):
     mppt_low: float
     mppt_high: float
-    pso: float
     paco: float
-    pdco: float
     vdco: float
+    pnt: float
+
+
+@dataclass_json
+@dataclass
+class ONDTemperatureDerateCurve(object):
+    ambient_temp: t.List[float]
+    max_ac_power: t.List[float]
+
+
+@dataclass_json
+@dataclass
+class ONDEfficiencyCurve(object):
+    dc_power: t.List[float]
+    ac_power: t.List[float]
+
+
+@dataclass_json
+@dataclass
+class ONDInverter(BaseInverter):
+    temp_derate_curve: ONDTemperatureDerateCurve
+    nominal_voltages: t.List[float]
+    power_curves: t.List[ONDEfficiencyCurve]
+    dc_turn_on: float
+    aux_loss: t.Optional[float] = opt_field()
+    aux_loss_threshold: t.Optional[float] = opt_field()
+    
+    @classmethod
+    def from_ond(cls, ond_file: str):
+        ond = read_pvsyst_file(ond_file)
+        data = ond['PVObject_']['items']
+        converter = data['Converter']['items']
+        voltage_curve_points = [float(v) for v in converter['VNomEff'].split(',') if v]
+        if len(voltage_curve_points) != 3:
+            raise NotImplementedError('OND Inverter only accepts voltage curves of length 3')
+        temp_derate_curve = ONDTemperatureDerateCurve(
+            ambient_temp=[-300, float(converter['TPMax']), float(converter['TPNom']), float(converter['TPLim1']), float(converter['TPLimAbs'])],
+            max_ac_power=[float(converter['PMaxOUT']) * 1e3, float(converter['PMaxOUT']) * 1e3, float(converter['PNomConv']) * 1e3, float(converter['PLim1']) * 1e3, float(converter.get('PlimAbs', 0.)) * 1e3]
+        )
+        raw_power_curves = [converter[f"ProfilPIOV{i}"]['items'] for i in [1, 2, 3]]
+        power_curves = []
+        for curve in raw_power_curves:
+            points = [[float(v) for v in curve[f"Point_{i}"].split(',')] for i in range(1, int(curve["NPtsEff"]) + 1)]
+            dc, ac = zip(*points)
+            power_curves.append(ONDEfficiencyCurve(dc_power=dc, ac_power=ac))
+        aux_loss = data.get('Aux_Loss')
+        aux_loss_threshold = data.get('Aux_Thresh')
+        if aux_loss is not None:
+            aux_loss = float(aux_loss)
+            aux_loss_threshold = float(aux_loss_threshold)
+        return cls(
+            mppt_low=float(converter['VMppMin']),
+            mppt_high=float(converter['VMPPMax']),
+            paco=float(converter['PMaxOUT']) * 1e3,
+            vdco=voltage_curve_points[1],
+            temp_derate_curve=temp_derate_curve,
+            nominal_voltages=voltage_curve_points,
+            power_curves=power_curves,
+            dc_turn_on=float(converter['PSeuil']),
+            pnt=float(data['Night_Loss']),
+            aux_loss=aux_loss,
+            aux_loss_threshold=aux_loss_threshold,
+        )
+    
+
+
+@dataclass_json
+@dataclass
+class Inverter(BaseInverter):
+    pso: float
+    pdco: float
     c0: float
     c1: float
     c2: float
     c3: float
-    pnt: float
     vdcmax: float
     tdc: t.List[t.List[float]] = field(default_factory=lambda: [[1.0, 52.8, -0.021]])
 
@@ -231,14 +300,15 @@ class SolarResource(object):
 @dataclass
 class PVModel(object):
     solar_resource: t.Union[t.Tuple[float, float], SolarResource]
-    inverter: t.Union[str, Inverter]
-    pv_module: t.Union[str, t.Union[PVModule, PVModuleMermoudLejeune]]
+    inverter: t.Union[str, BaseInverter]
+    pv_module: t.Union[str, PVModule, PVModuleMermoudLejeune]
     system_design: SystemDesign
     losses: t.Optional[Losses] = opt_field()
     layout: t.Optional[Layout] = opt_field()
     project_term: t.Optional[int] = None
     dc_degradation: t.Optional[float] = None
 
+
 DetailedPVModel = PVModel
 
 @dataclass_json
